/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.sensor.cropcircle;

import org.openide.util.NbPreferences;

/**
 * Cropcircle preferences, wraps the NbPreferences.forModule preference loader
 *
 * @author Timon Veenstra
 */
public enum CropcirclePreference {

    SENSOR_DATA_FILE_FORMAT("sensorDataFileFormat", "DDMMYYCC.CSV"),
    LOAD_DIR("loadDir", ""),
    ARCHIVE("archive", ""),
    LAST_DIR("lastDir", ""),
    DATABASE_DIR("dbDir", ""),
    LAST_SHAPE_DIR("lastShapeDir", ""),
    CROPCIRCLE_SENSOR_HEIGTH("cropCircleSensorHeight", "0"),
    NUMBER_OF_CROPCIRCLE_SENSORS("numberOfCropCircleSensors", "0"),
    CROPCIRCLE_SENSOR_SPREAD("cropCircleSensorSpread", ""),
    SENSOR_TYPE("sensorType", ""),
    SPECTRAL_CHANNELS("spectralRange", "");
    private String propertyName;
    private String defaultProperty;

    private CropcirclePreference(String propertyName, String defaultProperty) {
        this.propertyName = propertyName;
        this.defaultProperty = defaultProperty;
    }

    public String getDefaultProperty() {
        return defaultProperty;
    }

    public String getPropertyName() {
        return propertyName;
    }

    public String getValue() {
        return NbPreferences.forModule(this.getClass()).get(this.getPropertyName(), this.getDefaultProperty());
    }

    public void saveValue(String value) {
        NbPreferences.forModule(this.getClass()).put(this.getPropertyName(), value);
    }
}
