/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it
 * is applied to this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 * A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * AgroSense. If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.sensor.cropcircle.view;

import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;
import javax.swing.JComponent;
import nl.cloudfarming.client.logging.AppLogFactory;
import nl.cloudfarming.client.logging.AppLogger;
import nl.cloudfarming.client.sensor.cropcircle.CropcirclePreference;
import org.netbeans.spi.options.OptionsPanelController;
import org.openide.util.HelpCtx;
import org.openide.util.Lookup;
import org.openide.util.NbBundle;

@OptionsPanelController.SubRegistration(location = "Advanced",
displayName = "#OptionsCategory_Keywords_Sensormetadata",
keywords = "#OptionsCategory_Keywords_Sensormetadata",
keywordsCategory = "Advanced/CropcircleMetadata")
@NbBundle.Messages({"OptionsCategory_Keywords_Sensormetadata=Cropcirlcle metadata",
    "OptionsCategory_Name_Sensormetadata=Cropcirlcle metadata"})
public class CropcircleMetadataController extends OptionsPanelController {

    private final PropertyChangeSupport pcs = new PropertyChangeSupport(this);
    private boolean changed;
    private static final AppLogger LOG = AppLogFactory.getLogger(CropcircleMetadataController.class);
    private CropcircleMetadataPanel metadataPanel;

    @Override
    public void update() {
        load();
    }

    @Override
    public void applyChanges() {
        store();
    }

    @Override
    public void cancel() {
        // need not do anything special, if no changes have been persisted yet
    }

    @Override
    public boolean isValid() {
        return true;
    }

    @Override
    public boolean isChanged() {
        return true;
    }

    @Override
    public HelpCtx getHelpCtx() {
        return null; // new HelpCtx("...ID") if you have a help set
    }

    @Override
    public JComponent getComponent(Lookup masterLookup) {
        return getPanel();
    }

    @Override
    public void addPropertyChangeListener(PropertyChangeListener l) {
        pcs.addPropertyChangeListener(l);
    }

    @Override
    public void removePropertyChangeListener(PropertyChangeListener l) {
        pcs.removePropertyChangeListener(l);
    }

    public CropcircleMetadataPanel getPanel() {
        if (metadataPanel == null) {
            metadataPanel = new CropcircleMetadataPanel();
        }
        return metadataPanel;
    }

    void load() {
        getPanel().getDateFormatComboBox().setSelectedItem(CropcirclePreference.SENSOR_DATA_FILE_FORMAT.getValue());
        getPanel().getSensorTypeComboBox().setSelectedItem(CropcirclePreference.SENSOR_TYPE.getValue());
    }

    void store() {
        CropcirclePreference.SENSOR_DATA_FILE_FORMAT.saveValue(getPanel().getDateFormatComboBox().getSelectedItem().toString());
        CropcirclePreference.SENSOR_TYPE.saveValue(getPanel().getSensorTypeComboBox().getSelectedItem().toString());
    }
}
